@@ -1,51 +1,62 @@
 # Parallel Python Software: http://www.parallelpython.com
 # Copyright (c) 2005-2008, Vitalii Vanovschi
 # All rights reserved.
-# Redistribution and use in source and binary forms, with or without 
+# Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are met:
-#    * Redistributions of source code must retain the above copyright notice, 
+#    * Redistributions of source code must retain the above copyright notice,
 #      this list of conditions and the following disclaimer.
-#    * Redistributions in binary form must reproduce the above copyright 
-#      notice, this list of conditions and the following disclaimer in the 
+#    * Redistributions in binary form must reproduce the above copyright
+#      notice, this list of conditions and the following disclaimer in the
 #      documentation and/or other materials provided with the distribution.
-#    * Neither the name of the author nor the names of its contributors 
-#      may be used to endorse or promote products derived from this software 
+#    * Neither the name of the author nor the names of its contributors
+#      may be used to endorse or promote products derived from this software
 #      without specific prior written permission.
 #
-# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
-# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
-# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
-# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
-# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
-# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
-# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
-# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
-# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
-# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF 
+# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
+# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 # THE POSSIBILITY OF SUCH DAMAGE.
 
 """
 Parallel Python Software, Execution Server
 
-http://www.parallelpython.com - updates, documentation, examples and support 
+http://www.parallelpython.com - updates, documentation, examples and support
 forums
 """
 
-import os, thread, popen2, logging, inspect
-import sys, sha, types, time, atexit, user
+import os
+import thread
+import popen2
+import logging
+import inspect
+import sys
+import sha
+import types
+import time
+import atexit
+import user
 import cPickle as pickle
-import pptransport, ppauto
+import pptransport
+import ppauto
 
 copyright = "Copyright (c) 2005-2008 Vitalii Vanovschi. All rights reserved"
-version = "1.5.4"
+version = "1.5.6"
 
 # reconnect persistent rworkers in 5 sec
 _RECONNECT_WAIT_TIME = 5
 
 # we need to have set even in Python 2.3
-if not globals().has_key("set"):
+if "set" not in globals():
     from sets import Set as set
 
+
 class _Task(object):
     """Class describing single task (job)
     """
@@ -63,9 +74,10 @@ class _Task(object):
         self.finished = False
         self.unpickled = False
 
-    # for internal use only
     def finalize(self, sresult):
-        """Finalizes the task"""
+        """Finalizes the task.
+
+           For internal use only"""
         self.sresult = sresult
         if self.callback:
             self.__unpickle()
@@ -83,12 +95,12 @@ class _Task(object):
             return self.sresult
         else:
             return self.result
-    
+
     def wait(self):
         """Waits for the task"""
         if not self.finished:
-            self.lock.acquire() 
-            self.lock.release() 
+            self.lock.acquire()
+            self.lock.release()
 
     def __unpickle(self):
         """Unpickles the result of the task"""
@@ -97,7 +109,7 @@ class _Task(object):
         if len(sout) > 0:
             print sout,
         if self.callback:
-            args = self.callbackargs + (self.result,)
+            args = self.callbackargs + (self.result, )
             self.callback(*args)
 
 
@@ -122,7 +134,7 @@ class _Worker(object):
 
         self.pid = int(self.t.receive())
         self.is_free = True
-    
+
 
 class _RWorker(pptransport.CSocketTransport):
     """Remote worker class
@@ -136,7 +148,7 @@ class _RWorker(pptransport.CSocketTransport):
         self.secret = secret
         self.address = (host, port)
         self.id = host + ":" + str(port)
-        logging.debug("Creating Rworker id=%s persistent=%s" 
+        logging.debug("Creating Rworker id=%s persistent=%s"
                 % (self.id, persistent))
         self.connect(message)
         self.is_free = True
@@ -144,7 +156,7 @@ class _RWorker(pptransport.CSocketTransport):
     def __del__(self):
         """Closes connection with remote server"""
         self.close()
-    
+
     def connect(self, message=None):
         """Connects to a remote server"""
         while True:
@@ -161,12 +173,12 @@ class _RWorker(pptransport.CSocketTransport):
                 return True
             except:
                 if not self.persistent:
-                    logging.debug("Deleting from queue Rworker %s" 
-                            % (self.id,))
+                    logging.debug("Deleting from queue Rworker %s"
+                            % (self.id, ))
                     return False
 #                print sys.excepthook(*sys.exc_info())
                 logging.debug("Failed to reconnect with " \
-                        "(host=%s, port=%i), will try again in %i s" 
+                        "(host=%s, port=%i), will try again in %i s"
                         % (self.host, self.port, _RECONNECT_WAIT_TIME))
                 time.sleep(_RECONNECT_WAIT_TIME)
 
@@ -184,27 +196,25 @@ class _Statistics(object):
 
 
 class Template(object):
-    """Template class 
+    """Template class
     """
 
     def __init__(self, job_server, func, depfuncs=(), modules=(),
             callback=None, callbackargs=(), group='default', globals=None):
-        """ Creates Template instance
+        """Creates Template instance
 
-            jobs_server - pp server for submitting jobs
-            func - function to be executed
-            depfuncs - tuple with functions which might be called from 'func'
-            modules - tuple with module names to import
-            callback - callback function which will be called with argument 
-                    list equal to callbackargs+(result,) 
-                    as soon as calculation is done
-            callbackargs - additional arguments for callback function
-            group - job group, is used when wait(group) is called to wait for
-            jobs in a given group to finish
-            globals - dictionary from which all modules, functions and classes
-            will be imported, for instance: globals=globals()
-            
-        """
+           jobs_server - pp server for submitting jobs
+           func - function to be executed
+           depfuncs - tuple with functions which might be called from 'func'
+           modules - tuple with module names to import
+           callback - callback function which will be called with argument
+                   list equal to callbackargs+(result,)
+                   as soon as calculation is done
+           callbackargs - additional arguments for callback function
+           group - job group, is used when wait(group) is called to wait for
+           jobs in a given group to finish
+           globals - dictionary from which all modules, functions and classes
+           will be imported, for instance: globals=globals()"""
         self.job_server = job_server
         self.func = func
         self.depfuncs = depfuncs
@@ -217,36 +227,36 @@ class Template(object):
     def submit(self, *args):
         """Submits function with *arg arguments to the execution queue
         """
-        return self.job_server.submit(self.func, args, self.depfuncs
-                , self.modules, self.callback, self.callbackargs
-                , self.group, self.globals)
+        return self.job_server.submit(self.func, args, self.depfuncs,
+                self.modules, self.callback, self.callbackargs,
+                self.group, self.globals)
 
 
-class Server(object): 
+class Server(object):
     """Parallel Python SMP execution server class
     """
 
     default_port = 60000
     default_secret = "epo20pdosl;dksldkmm"
 
-    def __init__(self, ncpus="autodetect", ppservers=(), secret=None, 
+    def __init__(self, ncpus="autodetect", ppservers=(), secret=None,
             loglevel=logging.WARNING, logstream=sys.stderr):
-        """ Creates Server instance
-    
-            ncpus - the number of worker processes to start on the local 
-                    computer, if parameter is omitted it will be set to 
-                    the number of processors in the system
-            ppservers - list of active parallel python execution servers 
-                    to connect with
-            secret - passphrase for network connections, if omitted a default
-                    passphrase will be used. It's highly recommended to use a 
-                    custom passphrase for all network connections.
-            loglevel - logging level
-            logstream - log stream destination
-            
-            With ncpus = 1 all tasks are executed consequently
-            For the best performance either use the default "autodetect" value
-            or set ncpus to the total number of processors in the system
+        """Creates Server instance
+
+           ncpus - the number of worker processes to start on the local
+                   computer, if parameter is omitted it will be set to
+                   the number of processors in the system
+           ppservers - list of active parallel python execution servers
+                   to connect with
+           secret - passphrase for network connections, if omitted a default
+                   passphrase will be used. It's highly recommended to use a
+                   custom passphrase for all network connections.
+           loglevel - logging level
+           logstream - log stream destination
+
+           With ncpus = 1 all tasks are executed consequently
+           For the best performance either use the default "autodetect" value
+           or set ncpus to the total number of processors in the system
         """
 
         if not isinstance(ppservers, tuple):
@@ -256,8 +266,8 @@ class Server(object):
         logging.debug("Creating server instance (pp-" + version+")")
         self.__tid = 0
         self.__active_tasks = 0
-        self.__active_tasks_lock = thread.allocate_lock() 
-        self.__queue = []   
+        self.__active_tasks_lock = thread.allocate_lock()
+        self.__queue = []
         self.__queue_lock = thread.allocate_lock()
         self.__workers = []
         self.__rworkers = []
@@ -275,14 +285,14 @@ class Server(object):
         # add local directory and sys.path to PYTHONPATH
         pythondirs = [os.getcwd()] + sys.path
 
-        if os.environ.has_key("PYTHONPATH") and os.environ["PYTHONPATH"]:
+        if "PYTHONPATH" in os.environ and os.environ["PYTHONPATH"]:
             pythondirs += os.environ["PYTHONPATH"].split(os.pathsep)
         os.environ["PYTHONPATH"] = os.pathsep.join(set(pythondirs))
 
         atexit.register(self.destroy)
-        self.__stats = {"local":_Statistics(0)}
+        self.__stats = {"local": _Statistics(0)}
         self.set_ncpus(ncpus)
-        
+
         self.ppservers = []
         self.auto_ppservers = []
 
@@ -298,8 +308,10 @@ class Server(object):
             else:
                 if host == "*":
                     host = "*.*.*.*"
-                host = host.replace("*", "255")
-                self.auto_ppservers.append((host, port))
+                interface = host.replace("*", "0")
+                broadcast = host.replace("*", "255")
+                self.auto_ppservers.append(((interface, port),
+                        (broadcast, port)))
         self.__stats_lock = thread.allocate_lock()
         if secret is not None:
             if not isinstance(secret, types.StringType):
@@ -314,26 +326,25 @@ class Server(object):
             self.secret = Server.default_secret
         self.__connect()
         self.__creation_time = time.time()
-        logging.info("pp local server started with %d workers" 
-                % (self.__ncpus,))
+        logging.info("pp local server started with %d workers"
+                % (self.__ncpus, ))
 
-    def submit(self, func, args=(), depfuncs=(), modules=(), 
-            callback=None, callbackargs=(), group='default',globals=None):
+    def submit(self, func, args=(), depfuncs=(), modules=(),
+            callback=None, callbackargs=(), group='default', globals=None):
         """Submits function to the execution queue
 
             func - function to be executed
             args - tuple with arguments of the 'func'
             depfuncs - tuple with functions which might be called from 'func'
             modules - tuple with module names to import
-            callback - callback function which will be called with argument 
-                    list equal to callbackargs+(result,) 
+            callback - callback function which will be called with argument
+                    list equal to callbackargs+(result,)
                     as soon as calculation is done
             callbackargs - additional arguments for callback function
             group - job group, is used when wait(group) is called to wait for
             jobs in a given group to finish
             globals - dictionary from which all modules, functions and classes
             will be imported, for instance: globals=globals()
-            
         """
 
         # perform some checks for frequent mistakes
@@ -348,22 +359,22 @@ class Server(object):
 
         if not isinstance(modules, tuple):
             raise TypeError("modules argument must be a tuple")
-    
+
         if not isinstance(callbackargs, tuple):
             raise TypeError("callbackargs argument must be a tuple")
 
         for module in modules:
             if not isinstance(module, types.StringType):
                 raise TypeError("modules argument must be a list of strings")
-        
+
         tid = self.__gentid()
 
         if globals:
             modules += tuple(self.__find_modules("", globals))
             modules = tuple(set(modules))
-            self.__logger.debug("Task %i will autoimport next modules: %s" % 
+            self.__logger.debug("Task %i will autoimport next modules: %s" %
                     (tid, str(modules)))
-            for name, object1 in globals.items():
+            for object1 in globals.values():
                 if isinstance(object1, types.FunctionType) \
                         or isinstance(object1, types.ClassType):
                     depfuncs += (object1, )
@@ -376,30 +387,30 @@ class Server(object):
 
         # if the function is a method of a class add self to the arguments list
         if isinstance(func, types.MethodType) and func.im_self is not None:
-            args = (func.im_self,) + args
-    
-        # if there is an instance of a user deined class in the arguments add 
-        # whole class to dependancies 
+            args = (func.im_self, ) + args
+
+        # if there is an instance of a user deined class in the arguments add
+        # whole class to dependancies
         for arg in args:
             # Checks for both classic or new class instances
             if isinstance(arg, types.InstanceType) \
                     or str(type(arg))[:6] == "<class":
                 depfuncs += (arg.__class__, )
 
-        # if there is a function in the arguments add this 
+        # if there is a function in the arguments add this
         # function to dependancies
         for arg in args:
             if isinstance(arg, types.FunctionType):
                 depfuncs += (arg, )
 
-        sfunc = self.__dumpsfunc((func,)+depfuncs, modules)
+        sfunc = self.__dumpsfunc((func, ) + depfuncs, modules)
         sargs = pickle.dumps(args)
 
         self.__queue_lock.acquire()
         self.__queue.append((task, sfunc, sargs))
         self.__queue_lock.release()
 
-        self.__logger.debug("Task %i submited, function='%s'" % 
+        self.__logger.debug("Task %i submited, function='%s'" %
                 (tid, func.func_name))
         self.__scheduler()
         return task
@@ -425,7 +436,7 @@ class Server(object):
 
     def set_ncpus(self, ncpus="autodetect"):
         """Sets the number of local worker processes (ppworkers)
-        
+
         ncpus - the number of worker processes, if parammeter is omitted
                 it will be set to the number of processors in the system"""
         if ncpus == "autodetect":
@@ -441,11 +452,11 @@ class Server(object):
         self.__ncpus = ncpus
 
     def get_active_nodes(self):
-        """Returns active nodes as a dictionary 
+        """Returns active nodes as a dictionary
         [keys - nodes, values - ncpus]"""
         active_nodes = {}
         for node, stat in self.__stats.items():
-            if node == "local" or self.autopp_list.has_key(node) \
+            if node == "local" or node in self.autopp_list \
                     and self.autopp_list[node]:
                 active_nodes[node] = stat.ncpus
         return active_nodes
@@ -463,7 +474,7 @@ class Server(object):
         return self.__stats
 
     def print_stats(self):
-        """Prints job execution statistics. Useful for benchmarking on 
+        """Prints job execution statistics. Useful for benchmarking on
            clusters"""
 
         print "Job execution statistics:"
@@ -477,7 +488,7 @@ class Server(object):
         for ppserver, stat in statistics:
             if stat.njobs:
                 print "    %6i |        %6.2f |     %8.4f |  %11.6f | %s" \
-                        % (stat.njobs, 100.0*stat.njobs/totaljobs, stat.time, 
+                        % (stat.njobs, 100.0*stat.njobs/totaljobs, stat.time,
                         stat.time/stat.njobs, ppserver, )
         print "Time elapsed since server creation", walltime
 
@@ -489,7 +500,7 @@ class Server(object):
     # all methods below are for internal use only
 
     def insert(self, sfunc, sargs, task=None):
-        """Inserts function into the execution queue. It's intended for 
+        """Inserts function into the execution queue. It's intended for
            internal use only (ppserver.py).
         """
         if not task:
@@ -501,8 +512,7 @@ class Server(object):
 
         self.__logger.debug("Task %i inserted" % (task.tid, ))
         self.__scheduler()
-        return task        
-
+        return task
 
     def connect1(self, host, port, persistent=True):
         """Conects to a remote ppserver specified by host and port"""
@@ -533,7 +543,6 @@ class Server(object):
         except:
             pass
 #            sys.excepthook(*sys.exc_info())
-    
 
     def __connect(self):
         """Connects to all remote ppservers"""
@@ -542,29 +551,28 @@ class Server(object):
 
         discover = ppauto.Discover(self, True)
         for ppserver in self.auto_ppservers:
-            thread.start_new_thread(discover.run, (ppserver,))
-
+            thread.start_new_thread(discover.run, ppserver)
 
     def __detect_ncpus(self):
         """Detects the number of effective CPUs in the system"""
         #for Linux, Unix and MacOS
         if hasattr(os, "sysconf"):
-            if os.sysconf_names.has_key("SC_NPROCESSORS_ONLN"): 
+            if "SC_NPROCESSORS_ONLN" in os.sysconf_names:
                 #Linux and Unix
                 ncpus = os.sysconf("SC_NPROCESSORS_ONLN")
                 if isinstance(ncpus, int) and ncpus > 0:
                     return ncpus
-            else: 
+            else:
                 #MacOS X
                 return int(os.popen2("sysctl -n hw.ncpu")[1].read())
         #for Windows
-        if os.environ.has_key("NUMBER_OF_PROCESSORS"):
+        if "NUMBER_OF_PROCESSORS" in os.environ:
             ncpus = int(os.environ["NUMBER_OF_PROCESSORS"])
             if ncpus > 0:
                 return ncpus
         #return the default value
         return 1
-        
+
     def __initlog(self, loglevel, logstream):
         """Initializes logging facility"""
         log_handler = logging.StreamHandler(logstream)
@@ -577,8 +585,8 @@ class Server(object):
 
     def __dumpsfunc(self, funcs, modules):
         """Serializes functions and modules"""
-        hashs =  hash(funcs+modules)
-        if not self.__sfuncHM.has_key(hashs):
+        hashs = hash(funcs + modules)
+        if hashs not in self.__sfuncHM:
             sources = [self.__get_source(func) for func in funcs]
             self.__sfuncHM[hashs] = pickle.dumps(
                     (funcs[0].func_name, sources, modules))
@@ -613,16 +621,16 @@ class Server(object):
                 self.__add_to_active_tasks(1)
                 try:
                     self.__stats["local"].njobs += 1
-                    thread.start_new_thread(self.__run, task+(worker,))
+                    thread.start_new_thread(self.__run, task+(worker, ))
                 except:
                     pass
-            else: 
+            else:
                 for rworker in self.__rworkers:
                     if rworker.is_free:
                         rworker.is_free = False
                         task = self.__queue.pop(0)
                         self.__stats[rworker.id].njobs += 1
-                        thread.start_new_thread(self.__rrun, task+(rworker,))
+                        thread.start_new_thread(self.__rrun, task+(rworker, ))
                         break
                 else:
                     if len(self.__queue) > self.__ncpus:
@@ -631,8 +639,8 @@ class Server(object):
                                 rworker.is_free = False
                                 task = self.__queue.pop(0)
                                 self.__stats[rworker.id].njobs += 1
-                                thread.start_new_thread(self.__rrun, 
-                                        task+(rworker,))
+                                thread.start_new_thread(self.__rrun,
+                                        task+(rworker, ))
                                 break
                         else:
                             break
@@ -644,18 +652,18 @@ class Server(object):
                                         rworker.is_free = False
                                         task = self.__queue.pop(0)
                                         self.__stats[rworker.id].njobs += 1
-                                        thread.start_new_thread(self.__rrun, 
-                                                task+(rworker,))
+                                        thread.start_new_thread(self.__rrun,
+                                                task+(rworker, ))
                                         break
                     else:
                         break
-    
+
         self.__queue_lock.release()
-         
+
     def __get_source(self, func):
         """Fetches source of the function"""
         hashf = hash(func)
-        if not self.__sourcesHM.has_key(hashf):
+        if hashf not in self.__sourcesHM:
             #get lines of the source and adjust indent
             sourcelines = inspect.getsourcelines(func)[0]
             #remove indentation from the first line
@@ -665,7 +673,7 @@ class Server(object):
 
     def __rrun(self, job, sfunc, sargs, rworker):
         """Runs a job remotelly"""
-        self.__logger.debug("Task (remote) %i started" % (job.tid,))
+        self.__logger.debug("Task (remote) %i started" % (job.tid, ))
 
         try:
             rworker.csend(sfunc)
@@ -674,7 +682,7 @@ class Server(object):
             rworker.is_free = True
         except:
             self.__logger.debug("Task %i failed due to broken network " \
-                    "connection - rescheduling" % (job.tid,))
+                    "connection - rescheduling" % (job.tid, ))
             self.insert(sfunc, sargs, job)
             self.__scheduler()
             self.__update_active_rworkers(rworker.id, -1)
@@ -691,12 +699,15 @@ class Server(object):
             self.__waittasks.remove(job)
             self.__waittasks_lock.release()
 
-        self.__logger.debug("Task (remote) %i ended" % (job.tid,))
+        self.__logger.debug("Task (remote) %i ended" % (job.tid, ))
         self.__scheduler()
-    
+
     def __run(self, job, sfunc, sargs, worker):
         """Runs a job locally"""
-        self.__logger.debug("Task %i started" % (job.tid,))
+
+        if self.__exiting:
+            return
+        self.__logger.debug("Task %i started" % (job.tid, ))
 
         start_time = time.time()
 
@@ -709,9 +720,9 @@ class Server(object):
                 return
             else:
                 sys.excepthook(*sys.exc_info())
-                
+
         worker.is_free = True
-        
+
         job.finalize(sresult)
 
         # remove the job from the waiting list
@@ -723,10 +734,9 @@ class Server(object):
         self.__add_to_active_tasks(-1)
         if not self.__exiting:
             self.__stat_add_time("local", time.time()-start_time)
-        self.__logger.debug("Task %i ended" % (job.tid,))
+        self.__logger.debug("Task %i ended" % (job.tid, ))
         self.__scheduler()
 
-
     def __add_to_active_tasks(self, num):
         """Updates the number of active tasks"""
         self.__active_tasks_lock.acquire()
@@ -749,10 +759,10 @@ class Server(object):
         """Updates list of active rworkers"""
         self.__active_rworkers_list_lock.acquire()
 
-        if not self.autopp_list.has_key(id):
+        if id not in self.autopp_list:
             self.autopp_list[id] = 0
         self.autopp_list[id] += count
-        
+
         self.__active_rworkers_list_lock.release()
 
     def __gentid(self):
@@ -763,8 +773,12 @@ class Server(object):
     def destroy(self):
         """Kills ppworkers and closes open files"""
         self.__exiting = True
+        self.__queue_lock.acquire()
+        self.__queue = []
+        self.__queue_lock.release()
+
         for worker in self.__workers:
-            worker.t.close()
+            worker.t.exiting = True
             if sys.platform.startswith("win"):
                 os.popen('TASKKILL /PID '+str(worker.pid)+' /F')
             else:
@@ -774,4 +788,4 @@ class Server(object):
                 except:
                     pass
 
-# Parallel Python Software: http://www.parallelpython.com 
+# Parallel Python Software: http://www.parallelpython.com
