@@ -1,38 +1,44 @@
 # Parallel Python Software: http://www.parallelpython.com
 # Copyright (c) 2005-2008, Vitalii Vanovschi
 # All rights reserved.
-# Redistribution and use in source and binary forms, with or without 
+# Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are met:
-#    * Redistributions of source code must retain the above copyright notice, 
+#    * Redistributions of source code must retain the above copyright notice,
 #      this list of conditions and the following disclaimer.
-#    * Redistributions in binary form must reproduce the above copyright 
-#      notice, this list of conditions and the following disclaimer in the 
+#    * Redistributions in binary form must reproduce the above copyright
+#      notice, this list of conditions and the following disclaimer in the
 #      documentation and/or other materials provided with the distribution.
-#    * Neither the name of the author nor the names of its contributors 
-#      may be used to endorse or promote products derived from this software 
+#    * Neither the name of the author nor the names of its contributors
+#      may be used to endorse or promote products derived from this software
 #      without specific prior written permission.
 #
-# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
-# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
-# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
-# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
-# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
-# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
-# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
-# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
-# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
-# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF 
+# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
+# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 # THE POSSIBILITY OF SUCH DAMAGE.
 """
 Parallel Python Software, PP Transport
 
-http://www.parallelpython.com - updates, documentation, examples and support 
+http://www.parallelpython.com - updates, documentation, examples and support
 forums
 """
-import md5, os, struct, sha, socket, logging
+import md5
+import os
+import struct
+import sha
+import socket
+import logging
 
 copyright = "Copyright (c) 2005-2008 Vitalii Vanovschi. All rights reserved"
-version = "1.5.4"
+version = "1.5.6"
+
 
 class Transport(object):
 
@@ -48,7 +54,7 @@ class Transport(object):
         remote_version = self.receive()
         if version != remote_version:
             logging.error("PP version mismatch (local: pp-%s, remote: pp-%s)"
-                % (version, remote_version));
+                % (version, remote_version))
             logging.error("Please install the same version of PP on all nodes")
             return False
         srandom = self.receive()
@@ -62,10 +68,10 @@ class Transport(object):
 
     def close(self):
         pass
-    
+
     def _connect(self):
         pass
-        
+
 
 class CTransport(Transport):
     """Cached transport
@@ -77,33 +83,34 @@ class CTransport(Transport):
 
     def csend(self, msg):
         hash1 = self.hash(msg)
-        if self.scache.has_key(hash1):
+        if hash1 in self.scache:
             self.send("H" + hash1)
         else:
             self.send("N" + msg)
             self.scache[hash1] = True
-                
 
     def creceive(self, preprocess=None):
-        msg = self.receive()        
+        msg = self.receive()
         if msg[0] == 'H':
-            hash1 = msg[1:] 
+            hash1 = msg[1:]
         else:
             msg = msg[1:]
             hash1 = self.hash(msg)
-            self.rcache[hash1] = map(preprocess, (msg,))[0]
+            self.rcache[hash1] = map(preprocess, (msg, ))[0]
         return self.rcache[hash1]
 
 
 class PipeTransport(Transport):
+
     def __init__(self, r, w):
         self.scache = {}
+        self.exiting = False
         if isinstance(r, file) and isinstance(w, file):
             self.r = r
             self.w = w
         else:
-            raise TypeError("Both arguments of PipeTransport constructor must "\
-                    "be file objects")
+            raise TypeError("Both arguments of PipeTransport constructor " \
+                    "must be file objects")
 
     def send(self, msg):
         self.w.write(str(len(msg))+"\n")
@@ -115,10 +122,12 @@ class PipeTransport(Transport):
         try:
             msg_len = int(s)
         except ValueError:
+            if self.exiting:
+                return
             print "Literal for int() is: \"", s, "\""
             raise
         msg = self.r.read(msg_len)
-        return map(preprocess, (msg,))[0]
+        return map(preprocess, (msg, ))[0]
 
     def close(self):
         self.w.close()
@@ -143,7 +152,7 @@ class SocketTransport(Transport):
             if p_size == 0:
                 raise RuntimeError("Socket connection is broken")
             s_size += p_size
-    
+
         t_size = len(data)
         s_size = 0L
         while s_size < t_size:
@@ -160,17 +169,17 @@ class SocketTransport(Transport):
             msg = self.socket.recv(e_size-r_size)
             if msg == "":
                 raise RuntimeError("Socket connection is broken")
-            r_size += len(msg)        
+            r_size += len(msg)
             data += msg
         e_size = struct.unpack("!Q", data)[0]
-    
+
         r_size = 0
         data = ""
         while r_size < e_size:
             msg = self.socket.recv(e_size-r_size)
             if msg == "":
                 raise RuntimeError("Socket connection is broken")
-            r_size += len(msg)        
+            r_size += len(msg)
             data += msg
         return data
 
